package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````?10``#0```!<@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````5'(`
M`%1R```%`````!````$```#,?0``S(T``,R-``!X`@``I`(```8`````$```
M`@```-1]``#4C0``U(T``/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3,?0``S(T``,R-```T`@``-`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$P````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3````$T```!1````
M5@```%<```!>````7P```&``````````8@```&,`````````9````&4```!H
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````"!`````````#``<```````"0`````````P`1``$`````
M`````````!(````)```````````````2````$```````````````$0```/0!
M`````````````!$```!]`0`````````````2````%P``````````````$@``
M`,T!`````````````!(````?```````````````2````)@``````````````
M$@````$"`````````````!(```#9`0`````````````2````+P``````````
M````(````!L#`````````````"$```!'```````````````2````30``````
M````````$@```%0``````````````!(```#2`@`````````````2````\`(`
M````````````$@```%L``````````````!(````S`@`````````````2````
M8@``````````````$@```+D"`````````````!(```!I```````````````2
M````<0``````````````$@```,L"`````````````!(```!Y````````````
M```2````H@(`````````````$@```($``````````````!(```"*````````
M```````@````X@(`````````````$@```*8``````````````!(```"K````
M```````````2````F@$`````````````%@```,`"`````````````!(```!@
M`@`````````````2````L@``````````````$@```%("`````````````!(`
M``!?`P`````````````2````&@,`````````````$0```(0"````````````
M`!(````'`P`````````````2````$@(`````````````$@```!P#````````
M`````!$```"Y```````````````2````P@``````````````$0```(L!````
M`````````!(```#4```````````````B````XP``````````````(````/D`
M`````````````!(```#_`@`````````````2````<`(`````````````$@``
M`/X``````````````"````"M`@`````````````2````&`$`````````````
M$@```+X!`````````````!(````=`0`````````````2````D@(`````````
M````$@```",!`````````````!(```"M`0`````````````2````,0$`````
M````````$@```$(!`````````````!(````N`@`````````````2````/P(`
M````````````$@```$@!`````````````!(```!Y`@`````````````2````
MZ0(`````````````$@```-H"`````````````!(```!7`0`````````````2
M````*0(`````````````$@```%X!`````````````!(```!E`0``````````
M```2````&0,`````````````(0```'8!`````````````!(```!?!```<)``
M```````0`!(`%`,```$3``!\`0``$@`)`.X!``!),````@```!(`"@"A`P``
M^1\``/P#```2``D`;P0``*4E```X````$@`)`'X#``#)&P``!````!(`"0`3
M!```"1````(````2``<`Q`,``/4C``"P`0``$@`)`!D$``!$D````````!``
M$@!'!```S1L``'`!```2``D`_`,``$20````````$``2`(\#``"-'P``;```
M`!(`"0"N`P``;1H``$`````2``D`M@,``&$?```<````$@`)`-H#``#-+@``
MP@```!(`"0#O`P``/1T``!@````2``D`"`0``'"0````````$``2`&H$``!P
MD````````!``$@!$`P``F10``$`````2``D`)P0``%4=```$`0``$@`)`.4#
M``!`D```!````!$`$0!`!```1)`````````0`!$``00``'T4````````$@`)
M`!`$``"1+@``/````!(`"0!-`P``?1\``!`````2``D`:`,``/4:``#4````
M$@`)`%0$``"/+P``N````!(`"0!>!```<)`````````0`!(`,P0``%D>```(
M`0``$@`)``!O<&5N9&ER`&UE;6-M<`!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`
M<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED
M`'-T<F-M<`!M96US970`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!S=')R8VAR
M`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T
M<G-T<@!S=')C:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?
M9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`7TE435]R96=I
M<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E
M<G)N;U]L;V-A=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!M96UC<'D`<W1R
M;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4&5R
M;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,
M;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO
M8P!S=')C<'D`<F5A9&1I<@!S<')I;G1F`'-T<F1U<`!S=')T;VL`<'1H<F5A
M9%]A=&9O<FL`9G!R:6YT9@!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N
M`&QI8G!E<FPN<V\`;&EB8RYM=7-L+6%R;78W+G-O+C$`7W-T87)T7V,`9V5T
M7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP
M9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/
M3U0`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?8G-S7W-T
M87)T`%]?96YD7U\`<VAA7VEN:70`7U]B<W-?<W1A<G1?7P!P87)?9&ER;F%M
M90!P87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`
M7U]B<W-?96YD7U\`7V5N9`!P87)?8VQE86YU<``O=7-R+VQI8B]P97)L-2]C
M;W)E7W!E<FPO0T]210````#,C0``%P```-"-```7````P(\``!<```#,CP``
M%P```-B/```7`````)```!<````0D```%P```!20```7````')```!<````@
MD```%P```"20```7````*)```!<````LD```%P```#20```7````.)```!<`
M``!`D```%P```,2/```5!0``R(\``!4&``#0CP``%0X``-2/```5'P``W(\`
M`!,C``#@CP``%2T``.2/```5+P``Z(\``!4Q``#LCP``%3(``/"/```5-@``
M](\``!4[``#XCP``%3T``/R/```500``T(X``!8#``#4C@``%@0``-B.```6
M!P``W(X``!8(``#@C@``%@D``.2.```6"@``Z(X``!8+``#LC@``%@P``/".
M```6#0``](X``!8.``#XC@``%A```/R.```6$0```(\``!82```$CP``%A,`
M``B/```6%```#(\``!85```0CP``%A8``!2/```6%P``&(\``!88```<CP``
M%AD``""/```6&@``)(\``!8;```HCP``%AP``"R/```6'0``,(\``!8>```T
MCP``%B```#B/```6(0``/(\``!8B``!`CP``%B0``$2/```6)0``2(\``!8F
M``!,CP``%B<``%"/```6*```5(\``!8J``!8CP``%BL``%R/```6+```8(\`
M`!8N``!DCP``%C```&B/```6,0``;(\``!8R``!PCP``%C,``'2/```6-```
M>(\``!8U``!\CP``%C<``("/```6.```A(\``!8Y``"(CP``%CH``(R/```6
M/```D(\``!8^``"4CP``%C\``)B/```60```G(\``!9"``"@CP``%D,``*2/
M```61```J(\``!9%``"LCP``%D8``+"/```61P``M(\``!9(``"XCP``%DD`
M`+R/```62P```;6]Z`%`<$<$X"WE!."?Y0[@C^`(\+[EI'X```#&C^('RHSB
MI/Z\Y0#&C^('RHSBG/Z\Y0#&C^('RHSBE/Z\Y0#&C^('RHSBC/Z\Y0#&C^('
MRHSBA/Z\Y0#&C^('RHSB?/Z\Y0#&C^('RHSB=/Z\Y0#&C^('RHSB;/Z\Y0#&
MC^('RHSB9/Z\Y0#&C^('RHSB7/Z\Y0#&C^('RHSB5/Z\Y0#&C^('RHSB3/Z\
MY0#&C^('RHSB1/Z\Y0#&C^('RHSB//Z\Y0#&C^('RHSB-/Z\Y0#&C^('RHSB
M+/Z\Y0#&C^('RHSB)/Z\Y0#&C^('RHSB'/Z\Y0#&C^('RHSB%/Z\Y0#&C^('
MRHSB#/Z\Y0#&C^('RHSB!/Z\Y0#&C^('RHSB_/V\Y0#&C^('RHSB]/V\Y0#&
MC^('RHSB[/V\Y0#&C^('RHSBY/V\Y7A'_><`QH_B!\J,XMC]O.4`QH_B!\J,
MXM#]O.4`QH_B!\J,XLC]O.4`QH_B!\J,XL#]O.4`QH_B!\J,XKC]O.4`QH_B
M!\J,XK#]O.4`QH_B!\J,XJC]O.4`QH_B!\J,XJ#]O.4`QH_B!\J,XIC]O.4`
MQH_B!\J,XI#]O.4`QH_B!\J,XHC]O.4`QH_B!\J,XH#]O.4`QH_B!\J,XGC]
MO.4`QH_B!\J,XG#]O.4`QH_B!\J,XFC]O.4`QH_B!\J,XF#]O.4`QH_B!\J,
MXEC]O.4`QH_B!\J,XE#]O.4`QH_B!\J,XDC]O.4`QH_B!\J,XD#]O.4`QH_B
M!\J,XCC]O.4`QH_B!\J,XC#]O.4`QH_B!\J,XBC]O.4`QH_B!\J,XB#]O.4`
MQH_B!\J,XAC]O.5X1_WG`,:/X@?*C.(,_;SE`,:/X@?*C.($_;SE>$?]YP#&
MC^('RHSB^/R\Y0#&C^('RHSB\/R\Y0#&C^('RHSBZ/R\Y0#&C^('RHSBX/R\
MY0#&C^('RHSBV/R\Y0#&C^('RHSBT/R\Y0#&C^('RHSBR/R\Y0#&C^('RHSB
MP/R\Y7"UB+#-Z080!9(&J06J!ZA*3/_W:.]*2WQ$XU@#DTE+`YKC6!%&&$8$
MD__WT.Y&2^-8'>YP3QUXA;G_]Q[O0TIZ1-!@$+D!(/_W7N__]WKO.$M[1!MH
MXUB#^'M7-DL'F'M$&VCB6,4<DOC.,P0P0_`#`[#Q@$^"^,XS`=/_]R;O@`#_
M]U3O,DH#1GI$4&`&F@><$6@!8"])>41!8"Y)>40):(%@+4EY1$#X#!\!(8Q"
M.=P`+`3Q`P%/\``"3^J!`=B_$"$F3EI0)DD`DGY$*D;P:'E$__>P[@1&&+GP
M:/_W(.\$1B!-?43H:/_WY.X?2'A$`/`;^6"YJV@CN1Q(>$0`\!3YJ&`;2WM$
MF&@(L0'PR?@92WM$V&C_]UKO__<.[B!&"+!PO5+X(6`!,4#X!&^]YP"_AGP`
M`'A\``"H>P``.`$``#0!```$`0``''T``-)\``#*'P``GGP``+\?``"0?```
MUP8``'9\``"!'0``*!T``%1\``!(?```3_``"T_P``X#27E$:$8@\`\,Y48`
M\`+X2GD``!^U"TL+2GM$FE@"D@I*FE@#D@`B`9()2IM8`AT`DP%H`IL#F/_W
M@.X%L%WX!/L`OR)Z```4`0``_`````@!```&2`=+!TIX1'M$@T)Z1`/0!4O3
M6`.Q&$=P1P"_8GL``&![``#<>0``$`$```A("4MX1'M$&QK9#P=*`>NC`4D0
M>D0#T`5+TU@#L1A'<$<`OSA[```V>P``J'D``"P!```.2Q"U>T0.3!MX?$2C
MN0U+XU@CL0Q+>T08:/_W3N[_][__"DOC6!NQ"4AX1/_WE.T!(@A+>T0:<!"]
M`+\$>P``?GD``"0!``"N>@``#`$``.I<``#4>@``"+4'2P=*>T2;6"NQ!DD'
M2'E$>$3_]RKNO>@(0*KG`+\J>0``*`$``*1Z``"J7```&$LMZ?!'>T2*1@5&
M0+,62IM8'&@,LP-&'D83^`$K.KFA1G8;R$99^`1[)[D\1A3@/2KUT/#G,D8I
M1CA&__>*[0`H[]&[73TK[-&HZP0(3^JH`P$VRO@`,+P9($:]Z/"'!$;ZY_IX
M```<`0``![4-2@U+>D336&E&&V@!DT_P``/_][[_"4H(2WI$TU@::`&;6D!/
M\``#`=#_]T;N`[!=^`3[`+^.>```(`$``'AX``!SM15*%4MZ1--8!$8;:`&3
M3_```VY&$DU]1#%&($;_]Y?_6+D/2@U+>D336!IH`9M:0$_P``,-T/_W'NX*
M2P":ZU@;:`/K@@-::$/X!"L`*OK1XN<"L'"]2G@``"`!```X>```*'@``!P!
M```0M1=*%TMZ1*BPTUAI1@1&&V@GDT_P``/_]\SMV+D$FP/T<$.S]8!/`M"S
M]2!/!M$"(2!&__>F[+#Z@/!`"0I*"$MZ1--8&F@GFUI`3_```P/0__?<[0`@
M\><HL!"]`+_>=P``(`$``*)W```MZ?!#,DHS2WI$TUBIL!MH)Y-/\``#!4:P
ML0-XH['_]U[L!T:`L=_XL(#?^+"0^$3Y1#A&__>@[`1&B+DX1O_WWNPH1O_W
M8.TE2B)+>D336!IH)YM:0$_P``,VT/_WH.T3-$%&($;_]X+L`"CAT$E&($;_
M]WSL`"C;T"A&__>*[09&($;_]X;M,$0",/_WDNP&1A1)(T8J1GE$__=J[6E&
M,$;_]SCM`3`P1@O0!)L#]'!#L_6`3P71__>B_S!&__<^[;;G__=P[/CG*;"]
MZ/"#<'<``"`!``!G&0``9!D``"QW``#_&```+>GP1S9*-TNM]8`]AK!Z1--8
M#?6`,1MH2V%/\``#`B,`(@"3`",4,0=&__<@[`$X8?$`!A;P`$*#L@?5`3MO
MZ@-#;^H30P$S8NL"`M_XF)#$&M_XF(!FZP(&^40`+@/:3_#_,`%&).``(R)&
M`),X1C-&#?$,"O_W^NM"1E%&.$;_]\+L!R@$V:#Q"`551%5%!-*T]8`T9O$`
M!M_G""))1BA&__>NZYBYI>L*!2@91NOE<0]*"TMZ1`WU@#336!0T&F@C:%I`
M3_```P/0__?T[`$]W.<-]8`]!K"]Z/"'`+^"=@``(`$``'9W```(``$`VG4`
M`"WI\$\-1DI*2DMZ1--8A;`;:`.33_```PMX!D8]*PB_`34H1O_WR.P"J0=&
M,$;_]S7^W_@$D01&^42PL?_WO.R'0C/8`3P5^`$[!/@!/P`K^=$Z2C=+>D33
M6!IH`YM:0$_P``-@T/_WKNPU2UGX`Z#:^`"P6_@D,``K0M$Q2P3Q`@A[1!IH
M3^J("``J.]!!1EA&__=(Z\KX````*-G0`"+:^``P`I1#1$/X!"PS1AA&$_@!
M*PJQ/2KYT2%+@!M9^`-``C<X1-WX"(#4^`"0__>$ZTGX*```*+O0(VA3^"@@
M%O@!&Q-&$7`!,@FQ/2GWT3TB&G`5^`$K`_@!+P`J^=&GYP$TMN<!(D!&&F#_
M]V3K`9``*)W064:H\0@"__=BZP&;RO@`,+KG!;"]Z/"/`+^2=0``(`$``&1U
M``!&=0``'`$``+9V```7M`M+"TI[1)M8"$@!DWA$`&@=[G!/"$L(20&:(%A[
M1'E$`[!=^`1+__<"O%YU``!.=```,`$``"%7``!9%@``$[4,2QWN<$][1!MH
MX%C_]]?_`"((2`E+>$0`:'M$S>D`,@=)!TH@6'I$>43_]\[J`K`0O21U```4
M=0``F1@``"L6```="0``,+4O2B]+K?4`78>P>D336`WU`%$4,1MH"V!/\``#
M__?*ZBE*`ZQZ1`"2*$H#1D'R`0$@1GI$__>@ZD,<#]$`(R-)($IY1`WU`%"*
M6!0P$6@":%%`3_```BW0__?,Z[#U@%\`V?_>#?6`51`U($9/](!2*4;_]S;K
M!![@VV`<__?$Z@-&`"C:T*A"`M("&95"Z-.K0@+9*AF30N/30?(!`I1"W]PB
M1AA&*4;_]Y+K`"(#1@)5Q.<81@WU`%T'L#"]P',``"`!```(%@``[A4``(AS
M``#_]Y2_+>GP3T]*K?6%74]+@[!Z1`5&3DC36`Q&#?6%47A$!#$;:`M@3_``
M`__W&OTO(09&*$;_]\CJF+%%2"E&>$3_]XO^1$I`2WI$#?6%4=-8!#$::`MH
M6D!/\``#;=#_]U[K($;_]Y+J/$D\3WE$__<XZP1&W_CL@-_X[)!_1/A$^40`
M+-G0(W@`*PB_/$8NL2%&,$;_]RKJ`"A'T"!&__<XZP`A0QXC1)Q"`M(:>"\J
M'M`@1O_W+NN"1BA&__<JZX)$"O$!"KKU@%^VT@WQJ`NK\00*(T9"1D_T@%%0
M1LWI`)7_]][I`3"P]8!?`]G_W@/X`1G8YU!&`JG_]\KJJ+E;^)`\`_1P0[/U
M`$\.T0$A4$;_]\#I2+D42%%&>$3_]QS^4$;_]S+J!4:+YQ!)`"!Y1/_WUNH$
M1J/G*$8-]85=`["]Z/"/YG(``"`!```^%0``)Q4``*YR```&%0``EQ0``,(5
M``#T%```210``$(4```0M2\A!$;_]_3I`+%$'"!&O>@00/_W_KDPM3E*.4NM
M]8!=>D2#L`WU@%'36`0Q!48;:`M@3_```PBQ`WB[N3)*,$MZ1`WU@%'36`0Q
M&F@+:%I`3_```P'0__>HZBM(>$0-]8!=`["]Z#!`__?3N?_WF.H!,+#U@%\_
MV`&L*48@1O_WL.D@1O_WC.H`(@$X($2@0@+9`W@O*Q30+R$@1O_WJ.F0N1I*
M%TMZ1`WU@%'36`0Q&F@+:%I`3_```\S1%4AX1,WG`/@!*>+GH$*$OP`C`W`@
M1O_WH.D/2@I+>D0-]8!1TU@$,1IH"VA:0$_P``.RT0WU@%T#L#"]`"#LYP"_
M8G$``"`!``!"<0``0Q,``-QP``#A$@``J'```"U($+5X1/_W!_PL2"Q,>$3_
M]P+\*TA\1'A$__?]^RI(>$3_]_G[*4AX1/_W]?LH2'A$__?Q^R=(>$3_]^W[
M)DAX1/_WZ?L@1O_WYOLC2'A$__?B^R)(>$3_]][[(4AX1/_WN/L!1A"Q($;_
M]R_]'DAX1/_WK_L!1ABQ'$AX1/_W)?T;2'A$__>E^P%&4+$92'A$__<;_;WH
M$$`721=(>41X1!/E%DAX1/_WE/L!1@`H\=`42'A$[.?D$@``XQ(``!D3``#A
M$@``XA(``.$2``#I$@``EA(``.42``#K$@``@1(``.42``#D$@``ZA(``.T2
M```^$@``]!(``&D2``#;$@``<1(```5("+5X1/_W8?L@L0!X$+$P.!B_`2`(
MO1D2```(M?_WNNG_]Q+I`+$`:`B]][463P1&?T0X1O_W2?LA1@5&"+$#>"NY
M$4AX1`.PO>CP0+GD__?<Z+"Y($;_]Y#I!D8H1O_WC.DP1`(P__>8Z`9&"$L(
M22)&>40`E7M$__=NZ3%&.$;AYP.P\+U:$@``1A(``&01```V$@``+>GP1]Y*
MWTMZ1-],TUC$L'Q$&VA#DT_P``,$\1@.!/$,`RJM#?'`#`9&D^@'`(7H!P"^
MZ`\`K.@/`)[H`P`P-`WQM`B,Z`,`E.@'`(CH!P#.2,]/>$3_]^WZ?T0$1JBQ
M`WB;L?_WEO_*2L9+>D336!IH0YM:0$_P``,!T/_W..D@1D2PO>CP1__W9KC_
M]WK_!$8HN5CX!`L`*'#1ODQ\1"!&__<@Z4```3#_]RSH@$:!1M_XZ*(!//I$
M%/@!+P`J9]$-\<`)6?@$2X2Q($;_]['Z!$8`*/;0`W@`*_/0__<!^P`H[]`@
M1O_W..@$1JE&-+E9^`1;`"U<T"MX`"M/T2!&__?PZ()&0$;_]^SH@D0*\@1*
M4$;^]_;O!4:@2Z%)>T0`DZ!+(D9[1'E$S?@$@/_WQNA/].!Q*$;_]Z#H`3`Z
MT?_WEN@#:!$K-="72IA)N%@`DS)H*T8`:'E$__=>Z``DE$J'2WI$TU@::$.;
M6D!/\``#@M$@1D2PO>CPA__W6?H`*(;0`W@`*X/0_O?F[W[G2$911O_WE.@)
M\0()C.<H1O_WG_H`**/0*$;^]];O!$:=YRQ&H^<$K"%&*$;_]VSH@48HN2-I
M`_1P0[/U@$\)T'9+>$GX6#)H*T9Y1`!H__<<Z+SGU/@8@/_WB.B`1>_1(VG#
M\P@#L_7@?^G14$;^]X#O!$9M2'A$__<3^@%&`"AXT3=H.$;_]V3H`RB`1A[9
M9TD$.'E$.$3^]TCON+FX\00/!-"X1!CX!3PO*P_1=FANL3!&__=.Z`,H"-E=
M200X>40P1/[W,N\`*`B_-T;_]X+^@$8`*%31`48X1O[W?.\'1@`H3=#_]][Z
ML?$`"@9&1]NP\0H":O$``\WX`(`X1@WQV`C^]P;O048&(CA&_O?.[TA)0$9Y
M1`8B"C'^]\3N@$9PN[;Q,@)J\0`#`)`XKCA&_O?N[B@B,48X1O[WN.\^2SY)
M>T3-Z0!C/4LJ1B!&>T1Y1(WX"('^]^KO*$;^]\SO.$@A1GA$__<7^R!&__=(
M_BWG,&C_]V3\!T8`*('1?^<Q23)(>41X1/_W!OO^]\;N+TLP27M$S>D``R]+
M*D8@1GM$>43^]\+O+$XM3]_XM(!^1']$^$1/].!Q($;^]Y3O`3#*T?[WBN\#
M:!$KQ='^]Z;N"?$!"0"0,T8J1CE&($;-Z0&8_O>B[^7G`+_`;@``(`$``/AO
M``#:$```;FX``%QN``!F$0``4Q$``/D0``#F$```'A`````!``#$$```8FT`
M`'T0``#W#P``AA```%\0```+3P``DQ```-(/``!D#@``-@X``-H.``!K#@``
M01```(\/```2#@```@X``(T/```A$```<+542QWN<$][1!MHXUA;2)/X9"!X
M1(/X92#_]PWY(+$#>#$K`=%#>`NQ__<;_4I(4TEX1`!H`R,!(B!8>43^]ZCN
M!4:@L45+P6A[1!MH34H):.!8>D3^]ZCNZV@9:(MH6P(%U3Y+>T0;:.!8_O=`
M[CQ(14EX1`!H`R,!(B!8>43^]X;N!D;XL4!(>$3_]]3X`D9`L31+\6A[1!MH
M"6C@6/[W@NX0X/_W*_OQ:`5&`"@RT"Y+`D9[1!MH"6C@6/[W=.XH1O[WY.XI
M2S%)>T0;:.58`2)Y1"A&_O?"[2U*`49Z1"A&_O=@[B)+`")[1!MH*4CC6'A$
M@_AE(/_WG?@G3'Q$H&"`N6!H__=\_:!@6+DC2'A$_O>\[2)+>T1::!9+$FA[
M1!MHN><?3$_TX'%\1*!H_O>F[D(<`2H#1@C9$2@&T-3I`1(92`EH>$3^]Z#M
M<+T`O]QK``"R:P``FFL``'YK``!P:P``3&L``"YK```8:P``^&H``,)J``!9
M#0``K`X``)8.``!Q#@``L0P``!T.```F#@``/@P``&AK``#Z#0``3FL``#IK
M``#C#0``.+4$1O_WU/O_]\;[!4;_]]7\<+%LL2-X6[$&22A&>43^]]+MA4($
MT2!&O>@X0/_WN;@XO4\,```MZ?!/_4K^2WI$T[#36`&J%$8;:%&33_```P#Q
M7`4`\1P#4_@$&PFZG4)$^`0;^-$0)!%&#6I+:P$T:T"-:`EH:T!+0`0R3^KS
M<U`LTV/PT>A/T.D`Y@&9`FDY1-#X",`11,)HQ&B,Z@(",D!B0`'K_F$11`*:
MC.JV!3I$!>H.!2)$A>H,!4_JO@051`.:A.JV"@KJ`0HZ1(KJM@IB1))$!)H%
MZ_%EA.JQ"0GJ!0DZ1`+KM@*)Z@0)"NOU:I%$3^JU!06:A>JQ"`CJ"@@Z1")$
MB.JQ")!$!IH)Z_IIA>JZ!`3J"00Z1`+KL0)L0`CK^6@41$_JN0D'FHGJN@$!
MZ@@!.D0J1('JN@$11`B:!.OX9(GJN`4E0#I$`NNZ`H7J"04!Z_1A%41/ZK0$
M"9J$ZK@*"NH!"CI$2D2*ZK@*DD0*F@7K\66$ZK$)">H%"3I$`NNX`HGJ!`D*
MZ_5JD41/ZK4%"YJ%ZK$(".H*"#I$(D2(ZK$(D$0,F@GK^FF%ZKH$!.H)!#I$
M`NNQ`FQ`".OY:!1$3^JY"0V:B>JZ`0'J"`$Z1"I$@>JZ`1%$#IH$Z_ADB>JX
M!25`.D0"Z[H"A>H)!0'K]&$51$_JM`0/FH3JN`L+Z@$+.D1*1(OJN`N31!":
M!>OQ983JL0D)Z@4).D0"Z[@"B>H$"0OK]6N11$_JM041FH7JL0H*Z@L*.D0B
M1(KJL0J21!*:">O[:87JNP0Z1`KK^6H"Z[$"!.H)!!.93^JY"8GJNPAL0!1$
M".H*"!2:.40$Z_ID*42(ZKL(B>JZ!8A$)4!I23I$%9\(Z_1H`NN[`D_JM`2%
MZ@D%%40/1(3JN@*"Z@@"3T071!::!>OX90+K`0F$ZK@":D`)Z[H)D407F@?K
M]6=/ZK4%`NL!"H7JN`)Z0*)$DD08F@GK]VE4&(7JMP*"Z@D"!.NX!!1$&9H*
MZ_EJ3^JY"0+K`0B)ZK<"@NH*`JA$D$0:F@3K^F15&`7KMP6)ZKH"&Y\(Z_1H
M8D!/ZK0$%40/1(3JN@*"Z@@"3T071!R:!>OX90+K`0F$ZK@":D`)Z[H)D40=
MF@?K]6=/ZK4%`NL!"H7JN`)Z0*)$DD0>F@GK]VE4&(7JMP*"Z@D"!.NX!!1$
M'YH*Z_EJ3^JY"0+K`0B)ZK<"@NH*`JA$D$0@F@3K^F15&`7KMP6)ZKH"(9\(
MZ_1H8D!/ZK0$%40/1(3JN@*"Z@@"3T071"*:!>OX90+K`0F$ZK@":D`)Z[H)
MD40CF@?K]6=/ZK4%`NL!"H7JN`)Z0*)$DD0DF@GK]VE4&(7JMP*"Z@D"!.NX
M!!1$)9H*Z_EJ3^JY"0+K`0B)ZK<"@NH*`JA$D$0FF@3K^F15&`?@F7F"6J'K
MV6[<:```(`$```7KMP6)ZKH")Y\(Z_1H8D!/ZK0$%40/1(3JN@*"Z@@"3T07
M1"B:!>OX90+K`0F$ZK@"!^OU9VI`3^JU!0GKN@E%ZK@*D40*Z@<*!>JX`BF9
M2NH""NM*">OW:1%$(41%ZK<$BD0$Z@D$!>JW`0Q#*ID*Z_EJ$41/ZKD)`>NX
M`4GJMP@,1`CJ"@@)ZK<!2.H!""N9!.OZ9!%$*41)ZKH%B$0E0`GJN@$-0RR9
M".OT:!%$3^JT!`'KMP%$ZKH'#40'Z@@'!.JZ`0]#+9D%Z_AE$41)1$3JN`D/
M1`GJ!0D$ZK@!2>H!"2Z9!^OU9Q%$3^JU!0'KN@%%ZK@*B40*Z@<*!>JX`4KJ
M`0HOF0GK]VD11"%$1>JW!(I$!.H)!`7JMP$,0S"9"NOY:A%$3^JY"0'KN`%)
MZK<(#$0(Z@H(">JW`4CJ`0@QF03K^F011"E$2>JZ!8A$)4`)ZKH!#4,RF0CK
M]&@11$_JM`0!Z[<!1.JZ!PU$!^H(!P3JN@$/0S.9!>OX91%$241$ZK@)#T0)
MZ@4)!.JX`4GJ`0DTF0?K]6<11$_JM04!Z[H!1>JX"HE$"NH'"@7JN`%*Z@$*
M-9D)Z_=I$40A1$7JMP2*1`3J"00%ZK<!#$,VF0KK^6H11$_JN0D!Z[@!2>JW
M"`Q$".H*"`GJMP%(Z@$(-YD$Z_ID$40I1(A$2>JZ`0GJN@4A0"E#.)T(Z_1H
M%41/ZK0$!>NW!2E$1.JZ!03JN@<%Z@@%/4,YGP'K^&$71$]$1.JX"3U$">H!
M"03JN`=)Z@<).I\%Z_%E%T1/ZK$!!^NZ!T'JN`JY1`KJ!0H!ZK@'2NH'"CN?
M">OU:1=$)T1!ZK4$!.H)!%=$`>JU"D3J"@H\G`?K^6<41`3KN`0"\6U2"NL$
M"`+UX"(]G`+R^D)/ZKD)%$0,1(GJM0%Y0`Q$/ID(Z_=H$40!Z[4!B>JW!87J
M"`4I1#^=!.OX9!5$3^JX"*E$B.JW!65`J41`G0'K]&$51`7KMP6(ZK0'3T`]
M1$&?3^JQ"@GK\6D71(KJM`&!Z@D!1T0/1$*9!>OY91%$`>NT`8KJN01L0"%$
M0YP'Z_5G3^JU!03K`@B%ZKD$?$#01*!$1)P!Z_=A%$0$Z[D$A>JW"8GJ`0D(
MZ_%H3$1/ZK$)19D$Z_AD`>L""HGJMP&!Z@@!JD2*1$:9B>JX!1%$94`!Z[<!
M*41'G4_JM`L*Z_1J%42+ZK@$A.H*!$U$)41(G`'K^F$41(OJN@=/0`3KN`0\
M1$F?3^JQ"`7K\6471(CJN@%I0%]$#T1*F03K]62(ZK4)$42)Z@0)`>NZ`0?K
M]&=)1$_JM`E+G`'K]V$41*!$B>JU!'Q`H$1,G$_JL0H41`3KM02)ZK<%34`L
M1`'@W+P;CTV=".OQ:!5$3IE-1(KJMPF)Z@@)340!ZP()!.OX9`GKMPF*ZK@'
M`:MG0+E$T_@X<=/X/#$%Z_1E3^JT!!=$A.JX`1-$">OU:83JM0)I0%=$<T2"
MZ@D"#T0#Z[@#!^OY9Q-$`^OW8P-@#.NY`X-@PV@+2@/KM04#:3Y$'$0)2WI$
M1F#%8`1ATU@::%&;6D!/\``#`=#^]S3J4["]Z/"/`+]:8```(`$```BU8"#^
M]S+I"DH+20)@`O&(,D)@`O$I0J+UEA*B]HMB@F"B\8@RPF``(L#I!!*"8<)E
M"+T!(T5G\.'2PRWI\$$61@5&0VG2`)L8*+^":4-A)+\!,H)A@VD,1@/K5G.#
M8<!M!?$<!P"SP/%`"+!%.$2HO[!&B$($T@#K"`.90@72_]X!ZP@#`=F80OCG
M0D8A1O[WT.GK;4-$0"OK9131*$:FZP@&1$3_]U'[!?%<"#\N#-R\0A_9NQF<
M0N'3,D8A1CA&_O>XZ>YEO>CP@;Q"!/%``PW91$73TSI&5/@$&YQ"0O@$&_G1
M*$9`/O_W+_O>Y_+2GT+OY^'2HQF?0MWG+>GP00'Q'`=+:8YI#$:`(9/Z@_C#
M\\4#6APX*@5&-KKY5`?K`@!#W0`APO%``O[WC.@@1O_W"_LX(@`A.$;^]X3H
M($;$Z15H__<!^^-X($8K<&.(:W`C:!L*JW`C:.MPXWDK<>.(:W%C:!L*JW%C
M:.MQXWHK<F.):W*C:!L*JW*C:.MRXWLK<^.):W/C:!L*JW/C:.MSXWPK=&.*
M:W0C:1L*JW0C:>MTO>CP0?[W(;D`(<+Q.`+"YP"_`;6]Z`%`<$<]````0```
M``L```!`````$````$`````F````0````#4```!``````P```$`````&````
M0````!0```!`````#@```$`````-````0````"4```!`````$@```$`````H
M````0`````(```!`````&````$`````)````0`````H```!`````````````
M```N+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N
M86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`97AE`%!!4E]414U0`%!!4E]0
M4D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`
M4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"
M54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$
M25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`)3`R>``E<R5S)7,E<P!P87(M
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES
M('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R
M871I;VXI"@!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E
M<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)3
M24].`#$N,#4W`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H`+64`+2T`55-%4@!54T523D%-10!414U01$E2
M`%1-4``O=&UP`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*
M<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E
M=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#
M(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P
M86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@
M/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F
M:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68[
M"FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S
M:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@
M;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS
M965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE
M("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B
M=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*
M)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^
M9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*
M8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^
M+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F
M:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?
M<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[
M"FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B
M72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@
M/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?
M7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G
M;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA
M;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R
M<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R
M7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#
M86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B
M)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M
M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H
M)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T
M<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T
M<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D
M8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B
M3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I
M<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N
M(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F
M+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER
M<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM
M>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D
M9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH
M6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\
M<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C
M)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]
M?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2![
M"FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U
M9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@
M>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R
M8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES
M='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D
M=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD
M(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE
M+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z
M("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]
M*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M
M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D
M9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P
M<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@
M0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ
M1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I
M<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N
M86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[
M"GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D
M8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A
M9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T
M($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@
M("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H
M)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL
M92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M
M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C
M;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U
M;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%2
M1U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*
M:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*
M?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E
M860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D
M8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE
M<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50
M871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z
M.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T
M92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@
M/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D
M97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*
M)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C
M=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*
M;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE
M<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`
M:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^
M(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO
M9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]
M("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N
M=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[
M"GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR
M87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T[
M"B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&
M24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B
M)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT
M*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT
M96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O
M("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]
M"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI
M('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN
M960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@
M)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA
M;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S
M:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?
M;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T
M*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@
M)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&
M:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D
M9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E
M<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O
M9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@
M6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A
M<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S
M<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@
M/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I
M(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L
M("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA
M;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H
M.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I
M97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E
M(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E
M<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,[
M"G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I
M9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K
M*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D
M8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@
M/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D
M<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A
M73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@
M/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S
M:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H
M+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I
M>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`[
M"G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O
M7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D
M9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[
M7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D
M;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92([
M"G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L
M;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N
M86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM
M;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H
M)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]
M"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.
M04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE
M('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA
M;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T
M<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L
M("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US
M("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?
M97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I
M"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*
M<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z
M.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]
M?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI
M;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P
M87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T]
M(#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#
M2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%2
M7R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[
M(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L
M971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC``!#
M04-(10`]````0`````L```!`````$````$`````F````0````#4```!`````
M`P```$`````&````0````!0```!`````#@```$`````-````0````"4```!`
M````$@```$`````H````0`````(```!`````&````$`````)````0`````H`
M``!`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"1%0``.14```$````D`P``
M`0```"\#```/````>P0```P````)$```#0```$DP```9````S(T``!L````$
M````&@```-"-```<````!````/7^_V\L`0``!0```*0(```&````%`(```H`
M``"9!```"P```!`````5``````````,```#$C@```@```.`!```4````$0``
M`!<````H#@``$0```$`-```2````Z````!,````(````&`````````#[__]O
M`0``"/K__V\0````````````````````````````````````````````````
M`````````-2-`````````````!`0```0$```$!```!`0```0$```$!```!`0
M```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```$!``
M`!`0```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```
M$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0
M$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0
M```0$```$!```!`0```0$```$!```!`0```0$```$!````$3````````````
M`$DP``````````````D0````````````````````````````````````````
M````````````D```"E!!4BYP;0H`````AC,``.$P````````PC$``+LQ``!Z
M,P``V#$``((S````````;#,``'$S````````BS,``$=#0SH@*$%L<&EN92`Q
M,BXR+C%?9VET,C`R,C`Y,C0M<C$P*2`Q,BXR+C$@,C`R,C`Y,C0`03(```!A
M96%B:0`!*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1H"'`$>!"(!
M`"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O
M=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````
M````````````````````````````````````````````````"P````$````"
M````%`$``!0!```8```````````````!`````````!,```#V__]O`@```"P!
M```L`0``Z`````,`````````!`````0````=````"P````(````4`@``%`(`
M`)`&```$`````P````0````0````)0````,````"````I`@``*0(``"9!```
M```````````!`````````"T````)`````@```$`-``!`#0``Z`````,`````
M````!`````@````V````"0```$(````H#@``*`X``.`!```#````$`````0`
M```(````/P````$````&````"!````@0```(```````````````"````````
M`#H````!````!@```!`0```0$```\`(`````````````!`````0```!%````
M`0````8`````$P```!,``$@=``````````````0`````````2P````$````&
M````2#```$@P```(```````````````"`````````%$````!`````@```%`P
M``!0,````$(`````````````!`````````!9`````0````(```!0<@``4'(`
M``0```````````````0`````````8P````X````#````S(T``,Q]```$````
M```````````$````!````&\````/`````P```-"-``#0?0``!```````````
M````!`````0```![````!@````,```#4C0``U'T``/`````$``````````0`
M```(````A`````$````#````Q(X``,1^```\`0`````````````$````!```
M`(D````!`````P````"0````@```1```````````````!`````````"/````
M"`````,```!$D```1(```"P```````````````0`````````E`````$````P
M`````````$2````U```````````````!`````0```)T````#``!P````````
M``!Y@```,P```````````````0`````````!`````P``````````````K(``
5`*T```````````````$`````````
